@@ -478,10 +478,10 @@ class SearchResultsWindow(CutetubeWindows):
         self.show() 
         searchTerms = self.searchString.replace(" ", "+")
         if username == None:
-            self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?vq=<%22" + searchTerms + "%22>&orderby=" + searchOrder
+            self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?vq=%s&orderby=%s" % (searchTerms, searchOrder)
             self.actionSearch.setVisible(True)
         else:
-            self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?author=" + username + "&vq=<%22" + searchTerms + "%22>&orderby=" + searchOrder
+            self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?author=%s&vq=%s&orderby=%s" (username, searchTerms, searchOrder)
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
         self.connect(self.yt, SIGNAL("dataLoaded(PyQt_PyObject)"), self.addVideo)
         self.connect(self.yt, SIGNAL("feedCompleted(bool)"), self.toggleBusy)        
