@@ -17,8 +17,6 @@ import re
 import time
 import os
 import shutil
-import locale
-import atom
 import gdata.youtube.service
 
 class YouTubeDataService(object):
